==> nextcloud-15.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/workflowengine/l10n/fi.js <==
OC.L10N.register(
    "workflowengine",
    {
    "Short rule description" : "Lyhyt sääntökuvaus",
    "Add rule" : "Lisää sääntö",
    "Reset" : "Palauta",
    "Save" : "Tallenna",
    "Saving…" : "Tallennetaan...",
    "Group list is empty" : "Ryhmälista on tyhjä",
    "Unable to retrieve the group list" : "Ryhmälistaa ei voitu noutaa",
    "Saved" : "Tallennettu",
    "Saving failed:" : "Tallennus epäonnistui:",
    "Add rule group" : "Lisää sääntöryhmä",
    "File MIME type" : "Tiedoston MIME-tyyppi",
    "is" : "on",
    "is not" : "ei ole",
    "matches" : "täsmää",
    "does not match" : "ei täsmää",
    "Example: {placeholder}" : "Esimerkki: {placeholder}",
    "File name" : "Tiedostonimi",
    "File size (upload)" : "Tiedostokoko (lähetys)",
    "less" : "pienempi",
    "less or equals" : "pienempi tai yhtä suuri kuin",
    "greater or equals" : "suurempi tai yhtä suuri kuin",
    "greater" : "suurempi",
    "File system tag" : "Järjestelmätunniste",
    "is tagged with" : "on merkitty tunnisteella",
    "is not tagged with" : "ei ole merkitty tunnisteella",
    "Select tag…" : "Valitse tunniste…",
    "Request remote address" : "Pyynnön etäosoite",
    "matches IPv4" : "täsmää IPv4-osoitteeseen",
    "does not match IPv4" : "ei täsmää IPv4-osoitteeseen",
    "matches IPv6" : "täsmää IPv6-osoitteeseen",
    "does not match IPv6" : "ei täsmää IPv6-osoitteeseen",
    "Request time" : "Pyynnön aika",
    "between" : "välillä",
    "not between" : "ei välillä",
    "Start" : "Alku",
    "End" : "Loppu",
    "Select timezone…" : "Valitse aikavyöhyke...",
    "Request URL" : "Pyynnön URL-osoite",
    "Predefined URLs" : "Ennalta määritellyt URL-osoitteet",
    "Files WebDAV" : "Tiedostot WebDAV",
    "Request user agent" : "Pyynnön user agent",
    "Sync clients" : "Synkronointisovellukset",
    "Android client" : "Android-sovellus",
    "iOS client" : "iOS-sovellus",
    "Desktop client" : "Työpöytäsovellus",
    "Thunderbird & Outlook addons" : "Thunderbird- & Outlook-lisäosat",
    "User group membership" : "Käyttäjäryhmäjäsenyys",
    "is member of" : "on jäsen",
    "is not member of" : "ei ole jäsen",
    "The given operator is invalid" : "Annettu operaattori on virheellinen",
    "The given regular expression is invalid" : "Määritetty säännöllinen lauseke on virheellinen",
    "The given file size is invalid" : "Annettu tiedoston koko on virheellinen",
    "The given tag id is invalid" : "Annettu tag id on virheellinen",
    "The given IP range is invalid" : "Annetut IP-arvot ovat virheelliset",
    "The given IP range is not valid for IPv4" : "Annetut IP-arvot eivät käy IPv4-osoitteisiin",
    "The given IP range is not valid for IPv6" : "Annetut IP-arvot eivät käy IPv6-osoitteisiin",
    "The given time span is invalid" : "Annettu aikaväli on virheellinen",
    "The given start time is invalid" : "Annettu aloitusaika on virheellinen",
    "The given end time is invalid" : "Annettu päättymisaika on virheellinen",
    "The given group does not exist" : "Annettua ryhmää ei ole",
    "Check %s is invalid or does not exist" : "Tarkistus %s on virheellinen tai sitä ei ole olemassa",
    "Operation #%s does not exist" : "Toimenpidettä #%s ei ole olemassa",
    "Operation %s does not exist" : "Toimenpidettä %s ei ole olemassa",
    "Operation %s is invalid" : "Toimenpide %s on virheellinen",
    "Check %s does not exist" : "Tarkistusta %s ei ole olemassa",
    "Check %s is invalid" : "Tarkistus %s on virheellinen",
    "Check #%s does not exist" : "Tarkistusta #%s ei ole olemassa",
    "Workflow" : "Työnkulku",
    "Files workflow engine" : "Tiedostojen työnkulkumoottori",
    "Open documentation" : "Avaa dokumentaatio",
    "Loading…" : "Ladataan…"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-15.0.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/workflowengine/l10n/fi.js <==
OC.L10N.register(
    "workflowengine",
    {
    "Short rule description" : "Lyhyt sääntökuvaus",
    "Add rule" : "Lisää sääntö",
    "Reset" : "Palauta",
    "Save" : "Tallenna",
    "Saving…" : "Tallennetaan...",
    "Group list is empty" : "Ryhmälista on tyhjä",
    "Unable to retrieve the group list" : "Ryhmälistaa ei voitu noutaa",
    "Saved" : "Tallennettu",
    "Saving failed:" : "Tallennus epäonnistui:",
    "Add rule group" : "Lisää sääntöryhmä",
    "File MIME type" : "Tiedoston MIME-tyyppi",
    "is" : "on",
    "is not" : "ei ole",
    "matches" : "täsmää",
    "does not match" : "ei täsmää",
    "Example: {placeholder}" : "Esimerkki: {placeholder}",
    "File name" : "Tiedostonimi",
    "File size (upload)" : "Tiedostokoko (lähetys)",
    "less" : "pienempi",
    "less or equals" : "pienempi tai yhtä suuri kuin",
    "greater or equals" : "suurempi tai yhtä suuri kuin",
    "greater" : "suurempi",
    "File system tag" : "Järjestelmätunniste",
    "is tagged with" : "on merkitty tunnisteella",
    "is not tagged with" : "ei ole merkitty tunnisteella",
    "Select tag…" : "Valitse tunniste…",
    "Request remote address" : "Pyynnön etäosoite",
    "matches IPv4" : "täsmää IPv4-osoitteeseen",
    "does not match IPv4" : "ei täsmää IPv4-osoitteeseen",
    "matches IPv6" : "täsmää IPv6-osoitteeseen",
    "does not match IPv6" : "ei täsmää IPv6-osoitteeseen",
    "Request time" : "Pyynnön aika",
    "between" : "välillä",
    "not between" : "ei välillä",
    "Start" : "Alku",
    "End" : "Loppu",
    "Select timezone…" : "Valitse aikavyöhyke...",
    "Request URL" : "Pyynnön URL-osoite",
    "Predefined URLs" : "Ennalta määritellyt URL-osoitteet",
    "Files WebDAV" : "Tiedostot WebDAV",
    "Request user agent" : "Pyynnön user agent",
    "Sync clients" : "Synkronointisovellukset",
    "Android client" : "Android-sovellus",
    "iOS client" : "iOS-sovellus",
    "Desktop client" : "Työpöytäsovellus",
    "Thunderbird & Outlook addons" : "Thunderbird- & Outlook-lisäosat",
    "User group membership" : "Käyttäjäryhmäjäsenyys",
    "is member of" : "on jäsen",
    "is not member of" : "ei ole jäsen",
    "The given operator is invalid" : "Annettu operaattori on virheellinen",
    "The given regular expression is invalid" : "Määritetty säännöllinen lauseke on virheellinen",
    "The given file size is invalid" : "Annettu tiedoston koko on virheellinen",
    "The given tag id is invalid" : "Annettu tag id on virheellinen",
    "The given IP range is invalid" : "Annetut IP-arvot ovat virheelliset",
    "The given IP range is not valid for IPv4" : "Annetut IP-arvot eivät käy IPv4-osoitteisiin",
    "The given IP range is not valid for IPv6" : "Annetut IP-arvot eivät käy IPv6-osoitteisiin",
    "The given time span is invalid" : "Annettu aikaväli on virheellinen",
    "The given start time is invalid" : "Annettu aloitusaika on virheellinen",
    "The given end time is invalid" : "Annettu päättymisaika on virheellinen",
    "The given group does not exist" : "Annettua ryhmää ei ole",
    "Check %s is invalid or does not exist" : "Tarkistus %s on virheellinen tai sitä ei ole olemassa",
    "Operation #%s does not exist" : "Toimenpidettä #%s ei ole olemassa",
    "Operation %s does not exist" : "Toimenpidettä %s ei ole olemassa",
    "Operation %s is invalid" : "Toimenpide %s on virheellinen",
    "Check %s does not exist" : "Tarkistusta %s ei ole olemassa",
    "Check %s is invalid" : "Tarkistus %s on virheellinen",
    "Check #%s does not exist" : "Tarkistusta #%s ei ole olemassa",
    "Files workflow engine" : "Tiedostojen työnkulkumoottori",
    "Open documentation" : "Avaa dokumentaatio",
    "Loading…" : "Ladataan…",
    "Workflow" : "Työnkulku"
},
"nplurals=2; plural=(n != 1);");
